@@ -86,6 +86,30 @@ test_that("Go to Definition works in single file", {
     expect_equal(length(result), 0)
 })
 
+test_that("Go to Definition works in untilted documents", {
+    skip_on_cran()
+    client <- language_client()
+
+    uri <- "untitled:Untitled-1"
+
+    client %>% did_open(uri = uri, text = c(
+        "my_fn <- function(x) {x + 1}",
+        "my_fn",
+        ".nonexistent"
+    ))
+
+    # first query a known function to make sure the file is processed
+    result <- client %>% respond_definition(NULL, c(1, 0), uri = uri)
+
+    expect_equal(result$range$start, list(line = 0, character = 0))
+    expect_equal(result$range$end, list(line = 0, character = 28))
+
+    # then query the missing function. The file is processed, don't need to retry
+    result <- client %>% respond_definition(NULL, c(2, 0), uri = uri, retry = FALSE)
+
+    expect_equal(length(result), 0)
+})
+
 test_that("Go to Definition works in scope with different assignment operators", {
     skip_on_cran()
     client <- language_client()
@@ -137,6 +161,56 @@ test_that("Go to Definition works in scope with different assignment operators",
     expect_equal(result$range$end, list(line = 4, character = 11))
 })
 
+test_that("Go to Definition works in scope with semi-colons", {
+    skip_on_cran()
+    client <- language_client()
+
+    single_file <- withr::local_tempfile(fileext = ".R")
+    writeLines(c(
+        "my_fn <- function(var1) {",
+        "  var2 <- 1;",
+        "  var3 = 2;",
+        "  3 -> var4;",
+        "  for (var5 in 1:10) {",
+        "    var1 + var2 + var3 + var4 + var5;",
+        "  }",
+        "}",
+        "my_fn(1)"
+    ), single_file)
+
+    client %>% did_save(single_file)
+
+    # first query a known function to make sure the file is processed
+    result <- client %>% respond_definition(single_file, c(8, 0))
+
+    expect_equal(result$range$start, list(line = 0, character = 0))
+    expect_equal(result$range$end, list(line = 7, character = 1))
+
+    result <- client %>% respond_definition(single_file, c(5, 5))
+
+    expect_equal(result$range$start, list(line = 0, character = 18))
+    expect_equal(result$range$end, list(line = 0, character = 22))
+
+    result <- client %>% respond_definition(single_file, c(5, 12))
+
+    expect_equal(result$range$start, list(line = 1, character = 2))
+    expect_equal(result$range$end, list(line = 1, character = 11))
+
+    result <- client %>% respond_definition(single_file, c(5, 20))
+
+    expect_equal(result$range$start, list(line = 2, character = 2))
+    expect_equal(result$range$end, list(line = 2, character = 10))
+
+    result <- client %>% respond_definition(single_file, c(5, 26))
+
+    expect_equal(result$range$start, list(line = 3, character = 2))
+    expect_equal(result$range$end, list(line = 3, character = 11))
+
+    result <- client %>% respond_definition(single_file, c(5, 34))
+
+    expect_equal(result$range$start, list(line = 4, character = 7))
+    expect_equal(result$range$end, list(line = 4, character = 11))
+})
 
 test_that("Go to Definition works on both sides of assignment", {
     skip_on_cran()
